@@ -2,7 +2,7 @@ package Net::DNS::RR::NSEC3;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: NSEC3.pm 1857 2021-12-07 13:38:02Z willem $)[2];
+our $VERSION = (qw$Id: NSEC3.pm 1910 2023-03-30 19:16:30Z willem $)[2];
 
 use base qw(Net::DNS::RR::NSEC);
 
@@ -26,8 +26,7 @@ eval { require Digest::SHA };		## optional for simple Net::DNS RR
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset ) = @_;
+	my ( $self, $data, $offset ) = @_;
 
 	my $limit = $offset + $self->{rdlength};
 	my $ssize = unpack "\@$offset x4 C", $$data;
@@ -67,15 +66,15 @@ sub _format_rdata {			## format rdata portion of RR string.
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	my $alg = $self->algorithm(shift);
-	$self->flags(shift);
-	my $iter = $self->iterations(shift);
-	my $salt = shift;
+	my $alg = $self->algorithm( shift @argument );
+	$self->flags( shift @argument );
+	my $iter = $self->iterations( shift @argument );
+	my $salt = shift @argument;
 	$self->salt($salt) unless $salt eq '-';
-	$self->hnxtname(shift);
-	$self->typelist(@_);
+	$self->hnxtname( shift @argument );
+	$self->typelist(@argument);
 	$self->{hashfn} = _hashfn( $alg, $iter, $self->{saltbin} );
 	return;
 }
@@ -104,51 +103,49 @@ sub algorithm {
 
 
 sub flags {
-	my $self = shift;
-
-	$self->{flags} = 0 + shift if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{flags} = 0 + $_ }
 	return $self->{flags} || 0;
 }
 
 
 sub optout {
-	my $self = shift;
-	if ( scalar @_ ) {
-		for ( $self->{flags} ) {
-			$_ = 0x01 | ( $_ || 0 );
-			$_ ^= 0x01 unless shift;
+	my ( $self, @value ) = @_;
+	for ( $self->{flags} |= 0 ) {
+		if ( scalar @value ) {
+			$_ |= 0x01;
+			$_ ^= 0x01 unless shift @value;
 		}
 	}
-	return 0x01 & ( $self->{flags} || 0 );
+	return $self->{flags} & 0x01;
 }
 
 
 sub iterations {
-	my $self = shift;
-
-	$self->{iterations} = 0 + shift if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{iterations} = 0 + $_ }
 	return $self->{iterations} || 0;
 }
 
 
 sub salt {
-	my $self = shift;
-	return unpack "H*", $self->saltbin() unless scalar @_;
-	return $self->saltbin( pack "H*", join "", map { /^"*([\dA-Fa-f]*)"*$/ || croak("corrupt hex"); $1 } @_ );
+	my ( $self, @value ) = @_;
+	return unpack "H*", $self->saltbin() unless scalar @value;
+	my @hex = map { /^"*([\dA-Fa-f]*)"*$/ || croak("corrupt hex"); $1 } @value;
+	return $self->saltbin( pack "H*", join "", @hex );
 }
 
 
 sub saltbin {
-	my $self = shift;
-
-	$self->{saltbin} = shift if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{saltbin} = $_ }
 	return $self->{saltbin} || "";
 }
 
 
 sub hnxtname {
-	my $self = shift;
-	$self->{hnxtname} = _decode_base32hex(shift) if scalar @_;
+	my ( $self, @name ) = @_;
+	for (@name) { $self->{hnxtname} = _decode_base32hex($_) }
 	return defined(wantarray) ? _encode_base32hex( $self->{hnxtname} ) : undef;
 }
 
@@ -498,7 +495,9 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC5155, RFC9077
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC5155|https://tools.ietf.org/html/rfc5155>
+L<RFC9077|https://tools.ietf.org/html/rfc9077>
 
 L<Hash Algorithms|http://www.iana.org/assignments/dnssec-nsec3-parameters>
 
