@@ -1,48 +1,42 @@
 package Net::DNS::RR::RRSIG;
 
-#
-# $Id: RRSIG.pm 1779 2020-05-11 09:11:17Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1779 $)[1];
-
-
 use strict;
 use warnings;
+our $VERSION = (qw$Id: RRSIG.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::RRSIG - DNS RRSIG resource record
 
 =cut
 
-
 use integer;
 
 use Carp;
-use MIME::Base64;
 use Time::Local;
 
-use Net::DNS::Parameters;
+use Net::DNS::Parameters qw(:type);
 
 use constant DEBUG => 0;
 
-use constant UTIL => defined eval 'use Scalar::Util 1.25; 1;';
+use constant UTIL => defined eval { require Scalar::Util; };
+
+eval { require MIME::Base64 };
 
 # IMPORTANT: Downstream distros MUST NOT create dependencies on Net::DNS::SEC	(strong crypto prohibited in many territories)
 use constant USESEC => defined $INC{'Net/DNS/SEC.pm'};		# Discover how we got here, without exposing any crypto
-								# Discourage static code analysers and casual greppers
-use constant DNSSEC => USESEC && defined eval join '', qw(r e q u i r e), ' Net::DNS', qw(:: SEC :: Private);
+use constant DNSSEC => USESEC && defined eval join '', qw(r e q u i r e), ' Net::DNS::SEC::Private';	## no critic
 
 my @index;
 if (DNSSEC) {
-	my $key = new Net::DNS::RR( type => 'DNSKEY', key => 'AwEAAQ==' );
-	foreach my $class ( map "Net::DNS::SEC::$_", qw(RSA DSA ECCGOST ECDSA EdDSA) ) {
-		my @algorithms = eval join '', qw(r e q u i r e), " $class; $class->_index";	# 1.14 API
-		@algorithms = grep eval { $key->algorithm($_); $class->verify( '', $key, '' ); 1 }, ( 1 .. 16 )
-				unless scalar(@algorithms);	# Grotesquely inefficient; but need to support older API
-		push @index, map( ( $_ => $class ), @algorithms );
+	foreach my $class ( map {"Net::DNS::SEC::$_"} qw(RSA DSA ECCGOST ECDSA EdDSA) ) {
+		my @algorithms = eval join '', qw(r e q u i r e), " $class; $class->_index";	## no critic
+		push @index, map { ( $_ => $class ) } @algorithms;
 	}
+	croak 'Net::DNS::SEC version not supported' unless scalar(@index);
 }
 
 my %DNSSEC_verify = @index;
@@ -55,13 +49,13 @@ my @field = qw(typecovered algorithm labels orgttl sigexpiration siginception ke
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset ) = @_;
+	my ( $self, $data, $offset ) = @_;
 
 	my $limit = $offset + $self->{rdlength};
 	@{$self}{@field} = unpack "\@$offset n C2 N3 n", $$data;
-	( $self->{signame}, $offset ) = decode Net::DNS::DomainName( $data, $offset + 18 );
+	( $self->{signame}, $offset ) = Net::DNS::DomainName->decode( $data, $offset + 18 );
 	$self->{sigbin} = substr $$data, $offset, $limit - $offset;
+	return;
 }
 
 
@@ -69,7 +63,7 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	my $signame = $self->{signame};
-	pack 'n C2 N3 n a* a*', @{$self}{@field}, $signame->canonical, $self->sigbin;
+	return pack 'n C2 N3 n a* a*', @{$self}{@field}, $signame->canonical, $self->sigbin;
 }
 
 
@@ -77,16 +71,18 @@ sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my $signame = $self->{signame};
-	my @sig64   = split /\s+/, encode_base64( $self->sigbin );
-	my @rdata   = ( map( $self->$_, @field ), $signame->string, @sig64 );
+	my @sig64   = split /\s+/, MIME::Base64::encode( $self->sigbin );
+	my @rdata   = ( map( { $self->$_ } @field ), $signame->string, @sig64 );
+	return @rdata;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	foreach ( @field, qw(signame) ) { $self->$_(shift) }
-	$self->signature(@_);
+	foreach ( @field, qw(signame) ) { $self->$_( shift @argument ) }
+	$self->signature(@argument);
+	return;
 }
 
 
@@ -94,64 +90,15 @@ sub _defaults {				## specify RR attribute default values
 	my $self = shift;
 
 	$self->sigval(30);
-}
-
-
-#
-# source: http://www.iana.org/assignments/dns-sec-alg-numbers
-#
-{
-	my @algbyname = (
-		'DELETE'	     => 0,			# [RFC4034][RFC4398][RFC8078]
-		'RSAMD5'	     => 1,			# [RFC3110][RFC4034]
-		'DH'		     => 2,			# [RFC2539]
-		'DSA'		     => 3,			# [RFC3755][RFC2536]
-					## Reserved	=> 4,	# [RFC6725]
-		'RSASHA1'	     => 5,			# [RFC3110][RFC4034]
-		'DSA-NSEC3-SHA1'     => 6,			# [RFC5155]
-		'RSASHA1-NSEC3-SHA1' => 7,			# [RFC5155]
-		'RSASHA256'	     => 8,			# [RFC5702]
-					## Reserved	=> 9,	# [RFC6725]
-		'RSASHA512'	     => 10,			# [RFC5702]
-					## Reserved	=> 11,	# [RFC6725]
-		'ECC-GOST'	     => 12,			# [RFC5933]
-		'ECDSAP256SHA256'    => 13,			# [RFC6605]
-		'ECDSAP384SHA384'    => 14,			# [RFC6605]
-		'ED25519'	     => 15,			# [RFC8080]
-		'ED448'		     => 16,			# [RFC8080]
-
-		'INDIRECT'   => 252,				# [RFC4034]
-		'PRIVATEDNS' => 253,				# [RFC4034]
-		'PRIVATEOID' => 254,				# [RFC4034]
-					## Reserved	=> 255,	# [RFC4034]
-		);
-
-	my %algbyval = reverse @algbyname;
-
-	my @algrehash = map /^\d/ ? ($_) x 3 : do { s/[\W_]//g; uc($_) }, @algbyname;
-	my %algbyname = @algrehash;				# work around broken cperl
-
-	sub _algbyname {
-		my $arg = shift;
-		my $key = uc $arg;				# synthetic key
-		$key =~ s/[\W_]//g;				# strip non-alphanumerics
-		my $val = $algbyname{$key};
-		return $val if defined $val;
-		return $key =~ /^\d/ ? $arg : croak qq[unknown algorithm "$arg"];
-	}
-
-	sub _algbyval {
-		my $value = shift;
-		$algbyval{$value} || return $value;
-	}
+	return;
 }
 
 
 sub typecovered {
-	my $self = shift;
-	$self->{typecovered} = typebyname(shift) if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{typecovered} = typebyname($_) }
 	my $typecode = $self->{typecovered};
-	typebyval($typecode) if defined wantarray && defined $typecode;
+	return defined $typecode ? typebyval($typecode) : undef;
 }
 
 
@@ -170,80 +117,75 @@ sub algorithm {
 
 
 sub labels {
-	my $self = shift;
-
-	$self->{labels} = 0 + shift if scalar @_;
-	$self->{labels} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{labels} = 0 + $_ }
+	return $self->{labels} || 0;
 }
 
 
 sub orgttl {
-	my $self = shift;
-
-	$self->{orgttl} = 0 + shift if scalar @_;
-	$self->{orgttl} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{orgttl} = 0 + $_ }
+	return $self->{orgttl} || 0;
 }
 
 
 sub sigexpiration {
-	my $self = shift;
-	$self->{sigexpiration} = _string2time(shift) if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{sigexpiration} = _string2time($_) }
 	my $time = $self->{sigexpiration};
 	return unless defined wantarray && defined $time;
 	return UTIL ? Scalar::Util::dualvar( $time, _time2string($time) ) : _time2string($time);
 }
 
 sub siginception {
-	my $self = shift;
-	$self->{siginception} = _string2time(shift) if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{siginception} = _string2time($_) }
 	my $time = $self->{siginception};
 	return unless defined wantarray && defined $time;
 	return UTIL ? Scalar::Util::dualvar( $time, _time2string($time) ) : _time2string($time);
 }
 
-sub sigex { &sigexpiration; }		## historical
+sub sigex { return &sigexpiration; }	## historical
 
-sub sigin { &siginception; }		## historical
+sub sigin { return &siginception; }	## historical
 
 sub sigval {
-	my $self = shift;
+	my ( $self, @value ) = @_;
 	no integer;
-	( $self->{sigval} ) = map int( 86400 * $_ ), @_;
+	return ( $self->{sigval} ) = map { int( 86400 * $_ ) } @value;
 }
 
 
 sub keytag {
-	my $self = shift;
-
-	$self->{keytag} = 0 + shift if scalar @_;
-	$self->{keytag} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{keytag} = 0 + $_ }
+	return $self->{keytag} || 0;
 }
 
 
 sub signame {
-	my $self = shift;
-
-	$self->{signame} = new Net::DNS::DomainName(shift) if scalar @_;
-	$self->{signame}->name if $self->{signame};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{signame} = Net::DNS::DomainName->new($_) }
+	return $self->{signame} ? $self->{signame}->name : undef;
 }
 
 
 sub sig {
-	my $self = shift;
-	return MIME::Base64::encode( $self->sigbin(), "" ) unless scalar @_;
-	$self->sigbin( MIME::Base64::decode( join "", @_ ) );
+	my ( $self, @value ) = @_;
+	return MIME::Base64::encode( $self->sigbin(), "" ) unless scalar @value;
+	return $self->sigbin( MIME::Base64::decode( join "", @value ) );
 }
 
 
 sub sigbin {
-	my $self = shift;
-
-	$self->{sigbin} = shift if scalar @_;
-	$self->{sigbin} || "";
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{sigbin} = $_ }
+	return $self->{sigbin} || "";
 }
 
 
-sub signature { &sig; }
+sub signature { return &sig; }
 
 
 sub create {
@@ -258,14 +200,14 @@ sub create {
 
 		# All the TTLs need to be the same in the data RRset.
 		my $ttl = $RR->ttl;
-		croak 'RRs in RRset do not have same TTL' if grep $_->ttl != $ttl, @$rrsetref;
+		croak 'RRs in RRset do not have same TTL' if grep { $_->ttl != $ttl } @$rrsetref;
 
 		my $private = ref($priv_key) ? $priv_key : Net::DNS::SEC::Private->new($priv_key);
 		croak 'unable to parse private key' unless ref($private) eq 'Net::DNS::SEC::Private';
 
-		my @label = grep $_ ne chr(42), $RR->{owner}->_wire;	# count labels
+		my @label = grep { $_ ne chr(42) } $RR->{owner}->_wire;	   # count labels
 
-		my $self = new Net::DNS::RR(
+		my $self = Net::DNS::RR->new(
 			name	     => $RR->name,
 			type	     => 'RRSIG',
 			class	     => 'IN',
@@ -382,77 +324,57 @@ sub verify {
 
 sub vrfyerrstr {
 	my $self = shift;
-	$self->{vrfyerrstr};
+	return $self->{vrfyerrstr};
 }
 
 
 ########################################
 
-sub _ordered($$) {			## irreflexive 32-bit partial ordering
-	use integer;
-	my ( $a, $b ) = @_;
+{
+	my @algbyname = (
+		'DELETE'	     => 0,			# [RFC4034][RFC4398][RFC8078]
+		'RSAMD5'	     => 1,			# [RFC3110][RFC4034]
+		'DH'		     => 2,			# [RFC2539]
+		'DSA'		     => 3,			# [RFC3755][RFC2536]
+					## Reserved	=> 4,	# [RFC6725]
+		'RSASHA1'	     => 5,			# [RFC3110][RFC4034]
+		'DSA-NSEC3-SHA1'     => 6,			# [RFC5155]
+		'RSASHA1-NSEC3-SHA1' => 7,			# [RFC5155]
+		'RSASHA256'	     => 8,			# [RFC5702]
+					## Reserved	=> 9,	# [RFC6725]
+		'RSASHA512'	     => 10,			# [RFC5702]
+					## Reserved	=> 11,	# [RFC6725]
+		'ECC-GOST'	     => 12,			# [RFC5933]
+		'ECDSAP256SHA256'    => 13,			# [RFC6605]
+		'ECDSAP384SHA384'    => 14,			# [RFC6605]
+		'ED25519'	     => 15,			# [RFC8080]
+		'ED448'		     => 16,			# [RFC8080]
 
-	return defined $b unless defined $a;			# ( undef, any )
-	return 0 unless defined $b;				# ( any, undef )
+		'INDIRECT'   => 252,				# [RFC4034]
+		'PRIVATEDNS' => 253,				# [RFC4034]
+		'PRIVATEOID' => 254,				# [RFC4034]
+					## Reserved	=> 255,	# [RFC4034]
+		);
 
-	# unwise to assume 64-bit arithmetic, or that 32-bit integer overflow goes unpunished
-	if ( $a < 0 ) {						# translate $a<0 region
-		$a = ( $a ^ 0x80000000 ) & 0xFFFFFFFF;		#  0	 <= $a < 2**31
-		$b = ( $b ^ 0x80000000 ) & 0xFFFFFFFF;		# -2**31 <= $b < 2**32
+	my %algbyval = reverse @algbyname;
+
+	foreach (@algbyname) { s/[\W_]//g; }			# strip non-alphanumerics
+	my @algrehash = map { /^\d/ ? ($_) x 3 : uc($_) } @algbyname;
+	my %algbyname = @algrehash;				# work around broken cperl
+
+	sub _algbyname {
+		my $arg = shift;
+		my $key = uc $arg;				# synthetic key
+		$key =~ s/[\W_]//g;				# strip non-alphanumerics
+		my $val = $algbyname{$key};
+		return $val if defined $val;
+		return $key =~ /^\d/ ? $arg : croak qq[unknown algorithm $arg];
 	}
 
-	return $a < $b ? ( $a > ( $b - 0x80000000 ) ) : ( $b < ( $a - 0x80000000 ) );
-}
-
-
-my $y1998 = timegm( 0, 0, 0, 1, 0, 1998 );
-my $y2026 = timegm( 0, 0, 0, 1, 0, 2026 );
-my $y2082 = $y2026 << 1;
-my $y2054 = $y2082 - $y1998;
-my $m2026 = int( 0x80000000 - $y2026 );
-my $m2054 = int( 0x80000000 - $y2054 );
-my $t2082 = int( $y2082 & 0x7FFFFFFF );
-my $t2100 = 1960058752;
-
-sub _string2time {			## parse time specification string
-	my $arg = shift;
-	croak 'undefined time' unless defined $arg;
-	return int($arg) if length($arg) < 12;
-	my ( $y, $m, @dhms ) = unpack 'a4 a2 a2 a2 a2 a2', $arg . '00';
-	if ( $arg lt '20380119031408' ) {			# calendar folding
-		return timegm( reverse(@dhms), $m - 1, $y ) if $y < 2026;
-		return timegm( reverse(@dhms), $m - 1, $y - 56 ) + $y2026;
-	} elsif ( $y > 2082 ) {
-		my $z = timegm( reverse(@dhms), $m - 1, $y - 84 );    # expunge 29 Feb 2100
-		return $z < 1456790400 ? $z + $y2054 : $z + $y2054 - 86400;
+	sub _algbyval {
+		my $value = shift;
+		return $algbyval{$value} || return $value;
 	}
-	return ( timegm( reverse(@dhms), $m - 1, $y - 56 ) + $y2054 ) - $y1998;
-}
-
-
-sub _time2string {			## format time specification string
-	my $arg = shift;
-	croak 'undefined time' unless defined $arg;
-	my $ls31 = int( $arg & 0x7FFFFFFF );
-	if ( $arg & 0x80000000 ) {
-
-		if ( $ls31 > $t2082 ) {
-			$ls31 += 86400 unless $ls31 < $t2100;	# expunge 29 Feb 2100
-			my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 + $m2054 ) )[0 .. 5] );
-			return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1984, $mm + 1, @dhms;
-		}
-
-		my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 + $m2026 ) )[0 .. 5] );
-		return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1956, $mm + 1, @dhms;
-
-
-	} elsif ( $ls31 > $y2026 ) {
-		my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 - $y2026 ) )[0 .. 5] );
-		return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1956, $mm + 1, @dhms;
-	}
-
-	my ( $yy, $mm, @dhms ) = reverse( ( gmtime $ls31 )[0 .. 5] );
-	return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1900, $mm + 1, @dhms;
 }
 
 
@@ -484,7 +406,7 @@ sub _CreateSigData {
 		my $suffix = $wild->canonical;
 		unshift @label, chr(42);			# asterisk
 
-		my @RR	  = map bless( {%$_}, ref($_) ), @$rrsetref;   # shallow RR clone
+		my @RR	  = map { bless( {%$_}, ref($_) ) } @$rrsetref;	   # shallow RR clone
 		my $rr	  = $RR[0];
 		my $class = $rr->class;
 		my $type  = $rr->type;
@@ -511,7 +433,7 @@ sub _CreateSigData {
 			$table{substr $canonical, $offset} = $canonical;
 		}
 
-		$sigdata = join '', $sigdata, map $table{$_}, sort keys %table;
+		$sigdata = join '', $sigdata, map { $table{$_} } sort keys %table;
 
 		if (DEBUG) {
 			my $i = 0;
@@ -527,33 +449,31 @@ sub _CreateSigData {
 }
 
 
-########################################
-
 sub _CreateSig {
 	if (DNSSEC) {
-		my $self = shift;
+		my ( $self, @argument ) = @_;
 
 		my $algorithm = $self->algorithm;
 		my $class     = $DNSSEC_siggen{$algorithm};
 
-		eval {
-			return $self->sigbin( $class->sign(@_) ) if $class;
-			die "algorithm $algorithm not supported\n";
-		} || croak "${@}signature generation failed";
+		return eval {
+			die "algorithm $algorithm not supported\n" unless $class;
+			$self->sigbin( $class->sign(@argument) );
+		} || return croak "${@}signature generation failed";
 	}
 }
 
 
 sub _VerifySig {
 	if (DNSSEC) {
-		my $self = shift;
+		my ( $self, @argument ) = @_;
 
 		my $algorithm = $self->algorithm;
 		my $class     = $DNSSEC_verify{$algorithm};
 
 		my $retval = eval {
-			return $class->verify( @_, $self->sigbin ) if $class;
-			die "algorithm $algorithm not supported\n";
+			die "algorithm $algorithm not supported\n" unless $class;
+			$class->verify( @argument, $self->sigbin );
 		};
 
 		unless ($retval) {
@@ -570,6 +490,74 @@ sub _VerifySig {
 }
 
 
+sub _ordered() {			## irreflexive 32-bit partial ordering
+	my ( $n1, $n2 ) = @_;
+
+	return 0 unless defined $n2;				# ( any, undef )
+	return 1 unless defined $n1;				# ( undef, any )
+
+	# unwise to assume 64-bit arithmetic, or that 32-bit integer overflow goes unpunished
+	use integer;
+	if ( $n2 < 0 ) {					# fold, leaving $n2 non-negative
+		$n1 = ( $n1 & 0xFFFFFFFF ) ^ 0x80000000;	# -2**31 <= $n1 < 2**32
+		$n2 = ( $n2 & 0x7FFFFFFF );			#  0	 <= $n2 < 2**31
+	}
+
+	return $n1 < $n2 ? ( $n1 > ( $n2 - 0x80000000 ) ) : ( $n2 < ( $n1 - 0x80000000 ) );
+}
+
+
+my $y1998 = timegm( 0, 0, 0, 1, 0, 1998 );
+my $y2026 = timegm( 0, 0, 0, 1, 0, 2026 );
+my $y2082 = $y2026 << 1;
+my $y2054 = $y2082 - $y1998;
+my $m2026 = int( 0x80000000 - $y2026 );
+my $m2054 = int( 0x80000000 - $y2054 );
+my $t2082 = int( $y2082 & 0x7FFFFFFF );
+my $t2100 = 1960058752;
+
+sub _string2time {			## parse time specification string
+	my $arg = shift;
+	return int($arg) if length($arg) < 12;
+	my ( $y, $m, @dhms ) = unpack 'a4 a2 a2 a2 a2 a2', $arg . '00';
+	if ( $arg lt '20380119031408' ) {			# calendar folding
+		return timegm( reverse(@dhms), $m - 1, $y ) if $y < 2026;
+		return timegm( reverse(@dhms), $m - 1, $y - 56 ) + $y2026;
+	} elsif ( $y > 2082 ) {
+		my $z = timegm( reverse(@dhms), $m - 1, $y - 84 );    # expunge 29 Feb 2100
+		return $z < 1456790400 ? $z + $y2054 : $z + $y2054 - 86400;
+	}
+	return ( timegm( reverse(@dhms), $m - 1, $y - 56 ) + $y2054 ) - $y1998;
+}
+
+
+sub _time2string {			## format time specification string
+	my $arg	 = shift;
+	my $ls31 = int( $arg & 0x7FFFFFFF );
+	if ( $arg & 0x80000000 ) {
+
+		if ( $ls31 > $t2082 ) {
+			$ls31 += 86400 unless $ls31 < $t2100;	# expunge 29 Feb 2100
+			my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 + $m2054 ) )[0 .. 5] );
+			return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1984, $mm + 1, @dhms;
+		}
+
+		my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 + $m2026 ) )[0 .. 5] );
+		return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1956, $mm + 1, @dhms;
+
+
+	} elsif ( $ls31 > $y2026 ) {
+		my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 - $y2026 ) )[0 .. 5] );
+		return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1956, $mm + 1, @dhms;
+	}
+
+	my ( $yy, $mm, @dhms ) = reverse( ( gmtime $ls31 )[0 .. 5] );
+	return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1900, $mm + 1, @dhms;
+}
+
+########################################
+
+
 1;
 __END__
 
@@ -577,14 +565,14 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name RRSIG typecovered algorithm labels
+    $rr = Net::DNS::RR->new('name RRSIG typecovered algorithm labels
 				orgttl sigexpiration siginception
 				keytag signame signature');
 
     use Net::DNS::SEC;
-    $sigrr = create Net::DNS::RR::RRSIG( \@rrset, $keypath,
-					sigex => 20191231010101
-					sigin => 20191201010101
+    $sigrr = Net::DNS::RR::RRSIG->create( \@rrset, $keypath,
+					sigex => 20231231010101
+					sigin => 20231201010101
 					);
 
     $sigrr->verify( \@rrset, $keyrr ) || die $sigrr->vrfyerrstr;
@@ -705,11 +693,11 @@ Create a signature over a RR set.
 
     $keypath = '/home/olaf/keys/Kbla.foo.+001+60114.private';
 
-    $sigrr = create Net::DNS::RR::RRSIG( \@rrsetref, $keypath );
+    $sigrr = Net::DNS::RR::RRSIG->create( \@rrsetref, $keypath );
 
-    $sigrr = create Net::DNS::RR::RRSIG( \@rrsetref, $keypath,
-					sigex => 20191231010101
-					sigin => 20191201010101
+    $sigrr = Net::DNS::RR::RRSIG->create( \@rrsetref, $keypath,
+					sigex => 20231231010101
+					sigin => 20231201010101
 					);
     $sigrr->print;
 
@@ -718,7 +706,7 @@ Create a signature over a RR set.
 
     $private = Net::DNS::SEC::Private->new($keypath);
 
-    $sigrr= create Net::DNS::RR::RRSIG( \@rrsetref, $private );
+    $sigrr= Net::DNS::RR::RRSIG->create( \@rrsetref, $private );
 
 
 create() is an alternative constructor for a RRSIG RR object.  
@@ -735,8 +723,8 @@ containing the private key as generated by dnssec-keygen.
 The optional remaining arguments consist of ( name => value ) pairs
 as follows:
 
-	sigex  => 20191231010101,	# signature expiration
-	sigin  => 20191201010101,	# signature inception
+	sigex  => 20231231010101,	# signature expiration
+	sigin  => 20231201010101,	# signature inception
 	sigval => 30,			# validity window (days)
 	ttl    => 3600			# TTL
 
@@ -833,7 +821,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -850,11 +838,12 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, L<Net::DNS::SEC>,
-RFC4034, RFC6840, RFC3755
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<Net::DNS::SEC>
+L<RFC4034|https://tools.ietf.org/html/rfc4034>
 
 L<Algorithm Numbers|http://www.iana.org/assignments/dns-sec-alg-numbers>
 
-L<BIND 9 Administrator Reference Manual|http://www.bind9.net/manuals>
+L<BIND Administrator Reference Manual|http://bind.isc.org/>
 
 =cut
